FUNCTION myhist, data, hrange, $
                min = dminIn, max = dmaxIn, bin = dbin, nbin = nbin
;+
; Name:
;           myhist
; Purpose:
;           compute a histogram, and its corresponding range
; 
; Calling sequence:
;
;          hist = myhist(data, hrange)
; 
; Keywords:
;          min:      minimum
;          max:      maximum value for the histogram
;          nbin:     set the bin-size to be (max-min)/nbin
;          bin:      bin size for the histogram (unless nbin is set)
; Output:
;          hist[]:    histogram
;          hrange[]:  range vector: ie hist[i] correspond to hrange[i]
;-
;  --------------- -
;= RHIST           - histogram w/ range
; ---------------------------------------------------------------------------
IF NOT keyword_set(dminIn) THEN dmin = min(data) ELSE dmin = dminIn
IF NOT keyword_set(dmaxIn) THEN dmax = max(data) ELSE dmax = dmaxIn
;
IF keyword_set(nbin) THEN dbin = (dmax-dmin)/(nbin-2)
;
IF NOT keyword_set(dbin) THEN dbin = 1.0
;
dmin = dmin-dbin*1.5
dmax = dmax+dbin*1.5
hh = histogram(data, min=dmin, max=dmax, binsize=dbin)
npts = long ( (dmax - dmin)/dbin + 1 )
hrange = findgen(npts)*dbin + dmin + dbin/2.0
;
return, hh
END
